% Conjugated pulses in the energy gauge
%
clear all;
global n M NTS NSYM NTL NTR time freq;
NTS=2048;     % Number of points in the normalized unit time
NSYM=1024;    % NTS=2*NSYM for conjugated pulses. 2*NSYM points in the normalized unit frequency
NTL=2;
NTR=2;
NEYE=2;       % Number of unty intervals used for the eye diagram build-up
NB=2;
n=9;          % PRBS exponent
M=2^n;        % Extended length of the PRBS pattern with one additional bit
freq=(-NTS/2:1/(2*NSYM):(NTS-1/NSYM)/2); % Normalized frequency axis. Normalization B=1/T
findex=(NTS*NSYM+1:NTS*NSYM+1+NB*2*NSYM);
fplot=freq(findex); % Unilateral normalized frequency axis for plotting functions
bindex=(NTS*NSYM+1-NB*2*NSYM:NTS*NSYM+1+NB*2*NSYM);
bplot=freq(bindex); % Bilateral normalized frequency axis for plotting functions
time=(-NSYM:1/NTS:NSYM-1/NTS); % Normalized time axis. Normalization T
tindex=(NTS*NSYM+1-NTL*NTS:NTS*NSYM+1+NTR*NTS); % Temporal axis for pulse representation. Pulse is identically zero outside tindex
tplot=time(tindex); % Normalized temporal axis in ps for plotting output pulse
pindex=(NTS*NSYM+1-NTL*NTS:NTS*NSYM+M*NTS+NTR*NTS); % Single pattern period plus NTL and NTR time step on respective sides
%
% Pulse selection
Pulse='ERRF';
%
switch Pulse
    case 'VWRC'
        FWHM=1;
        m=0.5;
        G=VWRCSPECTRUM(FWHM,m); % G(nu)
    case 'ERRF'
        Tau=0.25;
        Sigma=0.5;
        FWHM=1;
        G=ERFSPECTRUM(Sigma,Tau,FWHM);
end;
g=PULSE(G); % g(xi)
figure(1); % Provides the conjugated pulses representations in normalized time and frequency domains and the eye diagrams
Offset=0.05;
subplot(321);
plot(tplot,real(g(tindex)));
grid on;
xlabel('Normalized time \xi=t/T')
ylabel('Amplitude');
switch Pulse
    case 'VWRC', title([Pulse, ' pulse g(\xi) - ', '\Lambda=',num2str(FWHM),' m=',num2str(m)]);
    case 'ERRF', title([Pulse, ' pulse g(\xi) - ', '\Lambda=',num2str(FWHM),...
            ' \sigma=',num2str(Sigma),' \tau=',num2str(Tau)]);
end;
Max=max(real(g(tindex)));
Min=min(real(g(tindex)));
Amp=Max-Min;
axis([min(tplot), max(tplot), Min-Offset*Amp, Max+Offset*Amp]);
subplot(323);
plot(freq(bindex),real(G(bindex)));
grid on;
xlabel('Normalized frequency \nu=fT')
ylabel('Amplitude');
switch Pulse
    case 'VWRC', title([Pulse, ' spectrum G(\nu) - ', '\Lambda=',num2str(FWHM),' m=',num2str(m)]);
    case 'ERRF', title([Pulse, ' spectrum G(\nu) - ', '\Lambda=',num2str(FWHM),...
            ' \sigma=',num2str(Sigma),' \tau=',num2str(Tau)]);
end;
Max=max(real(G(bindex)));
Min=min(real(G(bindex)));
Amp=Max-Min;
axis([min(freq(bindex)), max(freq(bindex)), Min-Offset*Amp, Max+Offset*Amp]);
subplot(325);
g_pattern=zeros(1,2*NTS*NSYM);
g_pattern(NTS*NSYM+1-M*NTS:NTS*NSYM+2*M*NTS)=SEQNRZ([PRBS(n) 0],real(g(tindex)))-1/2;
g_eye=EYEMATRIX(g_pattern(pindex),NEYE); % g eye diagram
Eyeaxis=(-NEYE/2:1/NTS:NEYE/2); % Symmetric NEYE unity intervals
exponent= num2str(n);
if length(exponent)>1, exponent=[exponent(1,1) '^' exponent(1,2)]; end;
Eyemax=max(max(g_eye));
Eyemin=min(min(g_eye));
Eyeamp=Eyemax-Eyemin;
plot(Eyeaxis,g_eye);
if Eyeamp>0, axis([min(Eyeaxis) max(Eyeaxis) Eyemin-0.05*Eyeamp Eyemax+0.05*Eyeamp]); end;
grid on;
xlabel('Normalized time t/T')
ylabel('Amplitude');
switch Pulse
    case 'VWRC', title([Pulse, ' eye g(\xi) - PRBS 2^' exponent '-1', ' \Lambda=',num2str(FWHM),' m=',num2str(m)]);
    case 'ERRF', title([Pulse, ' eye g(\xi) - PRBS 2^' exponent '-1', ' \Lambda=',num2str(FWHM),...
            ' \sigma=',num2str(Sigma),' \tau=',num2str(Tau)]);
end;
% Conjugated pulse graphic
subplot(322);
plot(tplot,real(G(tindex)));
grid on;
xlabel('Normalized time \xi=t/T')
ylabel('Amplitude');
switch Pulse
    case 'VWRC', title([Pulse, ' pulse G(\xi) - ', '\Lambda=',num2str(FWHM),' m=',num2str(m)]);
    case 'ERRF', title([Pulse, ' pulse G(\xi) - ', '\Lambda=',num2str(FWHM),...
            ' \sigma=',num2str(Sigma),' \tau=',num2str(Tau)]);
end;
Max=max(real(G(tindex)));
Min=min(real(G(tindex)));
Amp=Max-Min;
axis([min(tplot), max(tplot), Min-Offset*Amp, Max+Offset*Amp]);
subplot(324);
plot(freq(bindex),real(g(bindex)));
grid on;
xlabel('Normalized frequency \nu=fT')
ylabel('Amplitude');
switch Pulse
    case 'VWRC', title([Pulse, ' spectrum g(\nu) - ', '\Lambda=',num2str(FWHM),' m=',num2str(m)]);
    case 'ERRF', title([Pulse, ' spectrum g(\nu) - ', '\Lambda=',num2str(FWHM),...
            ' \sigma=',num2str(Sigma),' \tau=',num2str(Tau)]);
end;
Max=max(real(g(bindex)));
Min=min(real(g(bindex)));
Amp=Max-Min;
axis([min(freq(bindex)), max(freq(bindex)), Min-Offset*Amp, Max+Offset*Amp]);
subplot(326);
G_pattern=zeros(1,2*NTS*NSYM);
G_pattern(NTS*NSYM+1-M*NTS:NTS*NSYM+2*M*NTS)=SEQNRZ([PRBS(n) 0],real(G(tindex)))-1/2;
G_eye=EYEMATRIX(G_pattern(pindex),NEYE); % g eye diagram
Eyeaxis=(-NEYE/2:1/NTS:NEYE/2); % Symmetric NEYE unity intervals
exponent= num2str(n);
if length(exponent)>1, exponent=[exponent(1,1) '^' exponent(1,2)]; end;
Eyemax=max(max(G_eye));
Eyemin=min(min(G_eye));
Eyeamp=Eyemax-Eyemin;
plot(Eyeaxis,G_eye);
if Eyeamp>0, axis([min(Eyeaxis) max(Eyeaxis) Eyemin-0.05*Eyeamp Eyemax+0.05*Eyeamp]); end;
grid on;
xlabel('Normalized time t/T')
ylabel('Amplitude');
switch Pulse
    case 'VWRC', title([Pulse, ' eye G(\xi) - PRBS 2^' exponent '-1', ' \Lambda=',num2str(FWHM),' m=',num2str(m)]);
    case 'ERRF', title([Pulse, ' eye G(\xi) - PRBS 2^' exponent '-1', ' \Lambda=',num2str(FWHM),...
            ' \sigma=',num2str(Sigma),' \tau=',num2str(Tau)]);
end;
figure(2);
Offset=0.05;
subplot(321);
plot(tplot,real(g(tindex)));
grid on;
xlabel('Normalized time \xi=t/T')
ylabel('Amplitude');
switch Pulse
    case 'VWRC', title([Pulse, ' pulse g(\xi) - ', '\Lambda=',num2str(FWHM),' m=',num2str(m)]);
    case 'ERRF', title([Pulse, ' pulse g(\xi) - ', '\Lambda=',num2str(FWHM),...
            ' \sigma=',num2str(Sigma),' \tau=',num2str(Tau)]);
end;
Max=max(real(g(tindex)));
Min=min(real(g(tindex)));
Amp=Max-Min;
axis([min(tplot), max(tplot), Min-Offset*Amp, Max+Offset*Amp]);
subplot(322);
g_pattern=zeros(1,2*NTS*NSYM);
g_pattern(NTS*NSYM+1-M*NTS:NTS*NSYM+2*M*NTS)=SEQNRZ([PRBS(n) 0],real(g(tindex)))-1/2;
g_eye=EYEMATRIX(g_pattern(pindex),NEYE); % g eye diagram
Eyeaxis=(-NEYE/2:1/NTS:NEYE/2); % Symmetric NEYE unity intervals
exponent= num2str(n);
if length(exponent)>1, exponent=[exponent(1,1) '^' exponent(1,2)]; end;
Eyemax=max(max(g_eye));
Eyemin=min(min(g_eye));
Eyeamp=Eyemax-Eyemin;
plot(Eyeaxis,g_eye);
if Eyeamp>0, axis([min(Eyeaxis) max(Eyeaxis) Eyemin-0.05*Eyeamp Eyemax+0.05*Eyeamp]); end;
grid on;
xlabel('Normalized time t/T')
ylabel('Amplitude');
switch Pulse
    case 'VWRC', title([Pulse, ' eye g(\xi) - PRBS 2^' exponent '-1', ' \Lambda=',num2str(FWHM),' m=',num2str(m)]);
    case 'ERRF', title([Pulse, ' eye g(\xi) - PRBS 2^' exponent '-1', ' \Lambda=',num2str(FWHM),...
            ' \sigma=',num2str(Sigma),' \tau=',num2str(Tau)]);
end;
hold on;

