% SEQNRZ returns the pulse data stream according to the PRBS sequence of
% length 2^n-1 and to the selected pulse p(t). The total number of time
% samples included in the data stream is given by the PRBS sequence length
% multiplied by the number of time samples in each unit time interval NTS.
% In order to have a periodic data stream with the periodicity of the
% PRBS and to the length of the selected pulse, a number NTR (number of
% significant unit time intervals to the right of the pulse center) must be
% added to the beginning of the sequence and a corresponding number NTL
% (number of significant unit time intervals to the left of the pulse
% center) must be added at the end of the PRBS sequence.
% p:	pulse defined over the significant number of unit intervals to left NTL % and to the right NTR of the pulse center: p=[1:(NTL+NTR)*NTS+1]
% Sequence: bit sequence for data stream
% The index of the pulse center corresponds is NTL*NTS+1.
% The total number of time samples required to build up the periodic PRBS sequence is given by Ns=(2^n-1+NTL+NTR)*NTS+1.
% The returned periodic data sequence has length (2^n-1)*NTS
function Stream=SEQNRZ(Sequence,p)
global  NTS NTL NTR M;
w=[Sequence(M+1-NTR:M) Sequence Sequence(1:NTL)]; % weight vector used to build up the data stream
s=zeros(1,(M+2*(NTL+NTR))*NTS); % time vector to build PRBS data stream
% pulse offset adjust
po=p-p(1);
for k=1:M+NTL+NTR,
    Ik=(k-1)*NTS+1;
    s(Ik:Ik+(NTL+NTR)*NTS)=s(Ik:Ik+(NTL+NTR)*NTS)+w(k)*po;
end;
% Period of the data stream over M time steps
Stream(1:M*NTS)=s((NTL+NTR)*NTS+1:(NTL+NTR+M)*NTS)+p(1);
Stream=[Stream Stream Stream]; % Three successive periods


function a=PRBS(n)
b(1:n)=1;
Mode='ON';
if n==7, k=1;
elseif n==9, k=4;
elseif n==11, k=2;
elseif n==15, k=1;
elseif n==20, k=17;
elseif n==23, k=5;
elseif n==31, k=3;
else
    disp('Warning: PRBS length assignment is not available');
    Mode='NO';
end;
a=zeros(1,2^n-1);
if strcmp(Mode,'ON'),
    for i=1:2^n-1
        a(i)=b(n);
        b0=EXOR(b(n),b(n-k));
        for j=1:n-1, b(n-j+1)=b(n-j); end;
        b(1)=b0;
    end;
else
    a=[];
end;
