% MATLAB code - Calculation of the impulse response of the square root of the 
% raised cosine spectrum
%
clear all;
NTS=512;
NSYM=512;
NTL=4;
NTR=4;
NB=2;
B=40e9;
T=1/B;
%
freq=(-NTS/2:1/(2*NSYM):(NTS-1/NSYM)/2); % Normalized frequency axis. Normalization B=1/T
findex=(NTS*NSYM+1:NTS*NSYM+1+NB*2*NSYM);
fplot=freq(findex)/T; % Unilateral dimensional frequency axis for plotting functions
bindex=(NTS*NSYM+1-NB*2*NSYM:NTS*NSYM+1+NB*2*NSYM);
bplot=freq(bindex)/T; % Bilateral dimensional frequency axis for plotting functions
time=(-NSYM:1/NTS:NSYM-1/NTS); % Normalized time axis. Normalization T
tindex=(NTS*NSYM+1-NTL*NTS:NTS*NSYM+1+NTR*NTS); % Temporal axis for pulse representation. Pulse is identically zero outside tindex
tplot=time(tindex)*T*1e12; % Dimensional temporal axis in ps for plotting output pulse (ps)
%
G=zeros(1,2*NTS*NSYM);
G(NTS*NSYM+1-2*NSYM:NTS*NSYM+1+2*NSYM)=cos(pi*freq(NTS*NSYM+1-2*NSYM:NTS*NSYM+1+2*NSYM)/2);
RC=G.*G;
rc=ifftshift(ifft(fftshift(RC)))*NTS;
g=ifftshift(ifft(fftshift(G)))*NTS;
figure(1);
subplot(211);
plot(freq(bindex),G(bindex));
grid on;
xlabel('Normalized frequency fT')
ylabel('Normalized amplitude T');
title('Square-root of the raised cosine spectrum G(f)');
subplot(212);
plot(time(tindex),g(tindex));
grid on;
xlabel('Normalized time t/T')
ylabel('Amplitude');
title('Square-root of the raised cosine pulse g(t)');
figure(2);
subplot(211);
plot(freq(bindex),RC(bindex));
grid on;
xlabel('Normalized frequency fT')
ylabel('Normalized amplitude T');
title('Raised cosine spectrum \Gamma(f)');
subplot(212);
plot(time(tindex),rc(tindex));
grid on;
xlabel('Normalized time t/T')
ylabel('Amplitude');
title('Raised cosine pulse \gamma(t)');
